==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/proc/ProcCreateCmaterialOrderDetailItem.java <==
package global.hh.openapi.sdk.api.bean.proc;


/**
 * @description: 分销平台外部物料订单创建接口
 * @author: 777771
 * @date: 2023-18-27 10:18:35
 */
public class ProcCreateCmaterialOrderDetailItem {

    /**
     * 装箱规格
     */
    private String boxNorms;

    /**
     * NC转换数量
     */
    private String ncNum;

    /**
     * NC转换比
     */
    private String ncChange;

    /**
     * 单位
     */
    private String orderUnit;

    /**
     * 数量
     */
    private String gNum;

    /**
     * 单价
     */
    private String price;

    /**
     * 物料名称
     */
    private String cmaterialName;

    /**
     * 物料编码
     */
    private String cmaterialCode;

    public ProcCreateCmaterialOrderDetailItem(){
    }

    public ProcCreateCmaterialOrderDetailItem(String boxNorms,String ncNum,String ncChange,String orderUnit,String gNum,String price,String cmaterialName,String cmaterialCode){
        this.boxNorms=boxNorms;
        this.ncNum=ncNum;
        this.ncChange=ncChange;
        this.orderUnit=orderUnit;
        this.gNum=gNum;
        this.price=price;
        this.cmaterialName=cmaterialName;
        this.cmaterialCode=cmaterialCode;
    }

    private String getBoxNorms() {
        return boxNorms;
    }

    private void setBoxNorms(String boxNorms) {
        this.boxNorms = boxNorms;
    }
    private String getNcNum() {
        return ncNum;
    }

    private void setNcNum(String ncNum) {
        this.ncNum = ncNum;
    }
    private String getNcChange() {
        return ncChange;
    }

    private void setNcChange(String ncChange) {
        this.ncChange = ncChange;
    }
    private String getOrderUnit() {
        return orderUnit;
    }

    private void setOrderUnit(String orderUnit) {
        this.orderUnit = orderUnit;
    }
    private String getGNum() {
        return gNum;
    }

    private void setGNum(String gNum) {
        this.gNum = gNum;
    }
    private String getPrice() {
        return price;
    }

    private void setPrice(String price) {
        this.price = price;
    }
    private String getCmaterialName() {
        return cmaterialName;
    }

    private void setCmaterialName(String cmaterialName) {
        this.cmaterialName = cmaterialName;
    }
    private String getCmaterialCode() {
        return cmaterialCode;
    }

    private void setCmaterialCode(String cmaterialCode) {
        this.cmaterialCode = cmaterialCode;
    }
}

==> biostime-openapi-sdk-1.5.8.6-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/proc/ProcCreateCmaterialOrderDetailItem.java <==
package global.hh.openapi.sdk.api.bean.proc;


/**
 * @description: 分销平台外部物料订单创建接口
 * @author: 777771
 * @date: 2023-18-27 10:18:35
 */
public class ProcCreateCmaterialOrderDetailItem {

    /**
     * 装箱规格
     */
    private String boxNorms;

    /**
     * NC转换数量
     */
    private String ncNum;

    /**
     * NC转换比
     */
    private String ncChange;

    /**
     * 单位
     */
    private String orderUnit;

    /**
     * 数量
     */
    private String gNum;

    /**
     * 单价
     */
    private String price;

    /**
     * 物料名称
     */
    private String cmaterialName;

    /**
     * 物料编码
     */
    private String cmaterialCode;

    public ProcCreateCmaterialOrderDetailItem(){
    }

    public ProcCreateCmaterialOrderDetailItem(String boxNorms,String ncNum,String ncChange,String orderUnit,String gNum,String price,String cmaterialName,String cmaterialCode){
        this.boxNorms=boxNorms;
        this.ncNum=ncNum;
        this.ncChange=ncChange;
        this.orderUnit=orderUnit;
        this.gNum=gNum;
        this.price=price;
        this.cmaterialName=cmaterialName;
        this.cmaterialCode=cmaterialCode;
    }

    public String getBoxNorms() {
        return boxNorms;
    }

    public void setBoxNorms(String boxNorms) {
        this.boxNorms = boxNorms;
    }
    public String getNcNum() {
        return ncNum;
    }

    public void setNcNum(String ncNum) {
        this.ncNum = ncNum;
    }
    public String getNcChange() {
        return ncChange;
    }

    public void setNcChange(String ncChange) {
        this.ncChange = ncChange;
    }
    public String getOrderUnit() {
        return orderUnit;
    }

    public void setOrderUnit(String orderUnit) {
        this.orderUnit = orderUnit;
    }
    public String getGNum() {
        return gNum;
    }

    public void setGNum(String gNum) {
        this.gNum = gNum;
    }
    public String getPrice() {
        return price;
    }

    public void setPrice(String price) {
        this.price = price;
    }
    public String getCmaterialName() {
        return cmaterialName;
    }

    public void setCmaterialName(String cmaterialName) {
        this.cmaterialName = cmaterialName;
    }
    public String getCmaterialCode() {
        return cmaterialCode;
    }

    public void setCmaterialCode(String cmaterialCode) {
        this.cmaterialCode = cmaterialCode;
    }
}
